@@ -185,6 +185,48 @@ class TakemeClient:
 
         return response.get("data")
 
+    def user_bulk_inquiry_bank_account(self, list_bulk, jwt):
+        endpoint = "transaction/account-holdername-bulk"
+        body = {
+            "list_bulk": list_bulk
+        }
+
+        response = self.auth_call(body, endpoint, jwt)
+
+        return response.get("data")
+
+    def user_create_bulk_transfer(self, list_bank_account, reference, jwt):
+        endpoint = "transaction/transfer/bank/bulk"
+        body = {
+            "reference": reference,
+            "list_bulk": []
+        }
+
+        for x in list_bank_account:
+            body["list_bulk"].append({
+                "to_bank_account": {
+                    "name": x["account_name"],
+                    "bank_code": x["bank_name"],
+                    "account_number": x["account_number"],
+                },
+                "type": "TRANSFER_TO_BANK",
+                "notes": "Transfer",
+                "amount": x["amount"]
+            })
+
+        response = self.auth_call(body, endpoint, jwt)
+
+        return response.get("data")
+
+    def user_bulk_transfer(self, bulk_id, pin, jwt):
+        endpoint = "transaction/transfer/bank/bulk/%s" % (bulk_id)
+        print(endpoint)
+        body = {}
+
+        response = self.auth_call_with_pin(body, endpoint, jwt, pin)
+
+        return response.get("data")
+
     def corporate_inquiry_bank_account(self, account_number, bank_code):
         endpoint = "corporate/account-holdername"
         body = {
